import pandas as pd

class ARLManager:
    def __init__(self) -> None:
        self.graph_option = None
        self.filter_option = None
        self.filter_suboption = None
        self.interval_option = None
        self.interval_suboption = None

        self.default_compare_list = ["ขาเข้า", "ขาออก"]
        self.filter_option_list = ["รหัสสถานี", "ชื่อสถานี"]
        self.interval_option_list = ["วันในสัปดาห์ให้บริการ", "วันที่ให้บริการ", "เดือนที่ให้บริการ"]
        self.filter_suboption_list = []
        self.interval_suboption_list = []

        self.arl_df = pd.read_csv("arl_data_2565.csv")
        self.user_df = None
        self.graph_df = {
            "inbound" : self.user_df,
            "outbound" : self.user_df,
        }

    def set_suboption(self, type) -> None:
        match type:
            case "filter":
                if self.filter_option in self.filter_option_list:
                    self.filter_suboption_list = self.arl_df[self.filter_option].unique().astype("str").tolist()

            case "interval":
                if self.interval_option in self.interval_option_list:
                    self.interval_suboption_list = self.arl_df[self.interval_option].unique().astype("str").tolist()


    def set_user_df(self, type) -> None:
        self.user_df = self.arl_df.copy()[self.filter_option_list + self.default_compare_list + self.interval_option_list]

        if self.filter_option == "Please select filter option" or self.filter_suboption == "Please select filter sub-option":
            return None

        match type:    
            case "filter":
                if self.filter_suboption in self.filter_suboption_list:
                    self.user_df = self.user_df[self.user_df[self.filter_option].astype("str") == self.filter_suboption]

            case "interval":
                if self.interval_suboption in self.interval_suboption_list:
                    self.user_df = self.user_df[self.user_df[self.interval_option].astype("str") == self.interval_suboption]

            case _:
                raise ValueError("Invalid option type!")

        if self.filter_suboption is not None and self.interval_suboption is not None:
            self.user_df = self.user_df[(self.user_df[self.filter_option].astype("str") == self.filter_suboption)]


    def set_graph_df(self, type) -> None:
        match type:
            case "Histogram" | "Boxplot":
                self.graph_df["inbound"] = self.user_df["ขาเข้า"].tolist()
                self.graph_df["outbound"] = self.user_df["ขาออก"].tolist()


            case "Bar Chart" | "Line Chart":
                if self.filter_option == "Please select filter option":
                    self.filter_option = "รหัสสถานี"
                    self.set_suboption("filter")

                match self.interval_option:
                    case None:
                        return None
                    
                    case "Please select interval option" | "วันในสัปดาห์ให้บริการ" | "วันที่ให้บริการ":
                        grouped_df = self.user_df.copy().groupby(["เดือนที่ให้บริการ"], sort=False, as_index=False).sum()
                        self.graph_df["inbound"] = grouped_df["เดือนที่ให้บริการ"].tolist(), grouped_df["ขาเข้า"].tolist()
                        self.graph_df["outbound"] = grouped_df["เดือนที่ให้บริการ"].tolist(), grouped_df["ขาออก"].tolist()

                    case "เดือนที่ให้บริการ":
                        grouped_df = self.user_df.copy().groupby(["วันที่ให้บริการ"], sort=False, as_index=False).sum()
                        self.graph_df["inbound"] = grouped_df["วันที่ให้บริการ"].tolist(), grouped_df["ขาเข้า"].tolist()
                        self.graph_df["outbound"] = grouped_df["วันที่ให้บริการ"].tolist(), grouped_df["ขาออก"].tolist()

                    case _:
                        raise ValueError("Invalid interval option!")
                    
            case "Scatterplot":
                copied_df = self.user_df.copy()

                if self.filter_option == "Please select filter option":
                    self.filter_option = "รหัสสถานี"
                    self.set_suboption("filter")

                match self.interval_option:
                    case None:
                        return None
                    
                    case "Please select interval option":
                        self.graph_df["inbound"] = self.filter_suboption_list, copied_df["ขาเข้า"].tolist()
                        self.graph_df["outbound"] = self.filter_suboption_list, copied_df["ขาออก"].tolist()

                    case "วันในสัปดาห์ให้บริการ" | "วันที่ให้บริการ":
                        self.graph_df["inbound"] = copied_df["เดือนที่ให้บริการ"].tolist(), copied_df["ขาเข้า"].tolist()
                        self.graph_df["outbound"] = copied_df["เดือนที่ให้บริการ"].tolist(), copied_df["ขาออก"].tolist()

                    case "เดือนที่ให้บริการ":
                        self.graph_df["inbound"] = copied_df["วันที่ให้บริการ"].tolist(), copied_df["ขาเข้า"].tolist()
                        self.graph_df["outbound"] = copied_df["วันที่ให้บริการ"].tolist(), copied_df["ขาออก"].tolist()

                    case _:
                        raise ValueError("Invalid interval option!")