import matplotlib.pyplot as plt
from matplotlib.figure import Figure
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg

from dist_plotter import DistPlotter
from everyday_plotter import EverydayPlotter


class ARLVisualizer:
    def __init__(self, gui) -> None:
        # Set Thai Font properties
        plt.rcParams['font.family'] = 'Tahoma'
        plt.rcParams['font.size'] = 10

        self.gui = gui
        self.fig = Figure(figsize=(5,4))
        self.ax = self.fig.add_subplot(111)
        self.canvas = FigureCanvasTkAgg(self.fig, master=self.gui)

        self.dist_plotter = DistPlotter(self.gui, self.fig, self.ax, self.canvas)
        self.everyday_plotter = EverydayPlotter(self.gui, self.fig, self.ax, self.canvas)


    def graph_display(self, user_graph_type, graph_df) -> None:
        if user_graph_type == "Please select graph type":
            return None
        
        self.ax.cla()
        
        if user_graph_type in self.dist_plotter.graph_option_list:
            self.dist_plotter.draw_plot(user_graph_type, graph_df)

        elif user_graph_type in self.everyday_plotter.graph_option_list:
            self.everyday_plotter.draw_plot(user_graph_type, graph_df)
