class DistPlotter:
    def __init__(self, gui, fig=None, ax=None, canvas=None) -> None:
        self.graph_option_list = ["Histogram", "Boxplot"]
        self.gui = gui
        self.fig = fig
        self.ax = ax
        self.canvas = canvas

        self.inbound_hist_kwargs = {
            "color" : "green",
            "alpha" : 0.5,
            "bins" : 50,
            "label" : "Inbound",
        }

        self.outbound_hist_kwargs = {
            "color" : "firebrick",
            "alpha": 0.5,
            "bins": 50,
            "label" : "Outbound",
        }

        self.inbound_bp_kwargs = {
            "positions": [1],
            "widths": 0.5,
            "patch_artist": True,
            "boxprops": dict(facecolor="lightgreen", color="darkgreen"),
            "medianprops": dict(color="darkgreen"),
            "whiskerprops": dict(color="darkgreen"),
            "capprops": dict(color="darkgreen"),
            "flierprops": dict(marker="o", markerfacecolor="black"),
        }

        self.outbound_bp_kwargs = {
            "positions": [2],
            "widths": 0.5,
            "patch_artist": True,
            "boxprops": dict(facecolor="lightcoral", color="darkred"),
            "medianprops": dict(color="darkred"),
            "whiskerprops": dict(color="darkred"),
            "capprops": dict(color="darkred"),
            "flierprops": dict(marker="o", markerfacecolor="black"),
        }


    def draw_plot(self, graph_type, graph_df) -> None:
        match graph_type:
            case "Histogram":
                self.ax.hist(graph_df["inbound"], **self.inbound_hist_kwargs)
                self.ax.hist(graph_df["outbound"], **self.outbound_hist_kwargs)
                self.ax.set_xlabel("Interval of Passengers")
                self.ax.set_ylabel("Frequency")

            case "Boxplot":
                self.ax.boxplot(graph_df["inbound"], **self.inbound_bp_kwargs)
                self.ax.boxplot(graph_df["outbound"], **self.outbound_bp_kwargs)
                
                self.ax.set_xticklabels(["Inbound", "Outbound"])

            case _:
                raise ValueError("Invalid graph type!")
            
        self.ax.set_title(f"{graph_type} of Inbound/Outbound Passengers")
        self.ax.legend()
        self.canvas.draw()