import tkinter as tk
from tkinter import ttk
from abc import ABC, abstractclassmethod

from arl_visualizer import ARLVisualizer

class DropdownMaker(ABC):
    def __init__(self, gui, gui_dict, arl_m, option=None, suboption=None) -> None:
        self.gui = gui
        self.arl_m = arl_m
        self.data_view = gui_dict["data_view"]
        self.stats_view = gui_dict["stats_view"]
        self.option = option
        self.suboption = suboption

    def setup_dropdown(self) -> None:
        if self.option["dd"] is None:
            self.option["dd"] = ttk.Combobox(self.gui, textvariable=self.option["text"],\
                                            values=self.option["values"], font=("Tahoma", 12))
            self.option["dd"].bind("<<ComboboxSelected>>", self.update_dropdown)
            self.option["dd"].pack()

    def update_dropdown(self, event="<<ComboboxSelected>>") -> None:
        self.option["dd"].config(textvariable=self.option["text"])
        self.option["dd"].pack()
        self.update_settings()


    @abstractclassmethod
    def update_settings(self):
        pass


    def update_tree(self, tree_type):
        match tree_type:
            case "data_view":
                tree = self.data_view
                tree_df = self.arl_m.user_df

            case "stats_view":
                tree = self.stats_view
                tree_df = self.arl_m.user_df.describe().round(2)[self.arl_m.default_compare_list]\
                    .reset_index().rename(columns={'index': 'Statistics'})

        tree['columns'] = list(tree_df.columns)

        for item in tree.get_children():
            tree.delete(item)

        # set column headings
        for i in range(len(tree_df.columns)):
            col = tree_df.columns[i]
            tree.heading(i, text=col)

            width_scale = 10*len(tree_df.columns[i])
            tree.column(i, width=width_scale, anchor=tk.CENTER)
            # print(f"i = {i}, col = {col}")

        for i, row in tree_df.iterrows():
            tree.insert("", "end", text=i, values=list(row))


class FilterOptionMaker(DropdownMaker):
    def __init__(self, gui, gui_dict, arl_m, option=None, suboption=None) -> None:
        super().__init__(gui, gui_dict, arl_m, option, suboption)

    def update_settings(self) -> None:
        self.arl_m.filter_option = self.option["text"].get()
        self.arl_m.filter_suboption = self.suboption["text"].get()

        self.arl_m.set_suboption("filter")
        self.arl_m.set_user_df("filter")

        self.option["values"] = self.arl_m.filter_suboption_list
        self.suboption["dd"].config(values=self.option["values"])
        super().update_tree("data_view")
        super().update_tree("stats_view")


class FilterSuboptionMaker(DropdownMaker):
    def __init__(self, gui, gui_dict, arl_m, option=None, suboption=None) -> None:
        super().__init__(gui, gui_dict, arl_m, option, suboption)

    def setup_dropdown(self) -> None:
        if self.suboption["dd"] is None:
            self.suboption["dd"] = ttk.Combobox(self.gui, textvariable=self.suboption["text"],\
                                                values=self.suboption["values"], font=("Tahoma", 12))
            self.suboption["dd"].bind("<<ComboboxSelected>>", self.update_dropdown)
            self.suboption["dd"].pack()

    def update_settings(self) -> None:
        self.arl_m.filter_option = self.option["text"].get()
        self.arl_m.filter_suboption = self.suboption["text"].get()

        self.arl_m.set_user_df("filter")
        super().update_tree("data_view")
        super().update_tree("stats_view")



class IntervalOptionMaker(DropdownMaker):
    def __init__(self, gui, gui_dict, arl_m, option=None, suboption=None) -> None:
        super().__init__(gui, gui_dict, arl_m, option, suboption)

    def update_settings(self) -> None:
        self.arl_m.interval_option = self.option["text"].get()
        self.arl_m.interval_suboption = self.suboption["text"].get()

        self.arl_m.set_suboption("interval")
        self.arl_m.set_user_df("interval")

        self.option["values"] = self.arl_m.interval_suboption_list
        self.suboption["dd"].config(values=self.option["values"])
        super().update_tree("data_view")
        super().update_tree("stats_view")


class IntervalSuboptionMaker(DropdownMaker):
    def __init__(self, gui, gui_dict, arl_m, option=None, suboption=None) -> None:
        super().__init__(gui, gui_dict, arl_m, option, suboption)

    def setup_dropdown(self) -> None:
        if self.suboption["dd"] is None:
            self.suboption["dd"] = ttk.Combobox(self.gui, textvariable=self.suboption["text"],\
                                                values=self.suboption["values"], font=("Tahoma", 12))
            self.suboption["dd"].bind("<<ComboboxSelected>>", self.update_dropdown)
            self.suboption["dd"].pack()

    def update_settings(self) -> None:
        self.arl_m.interval_option = self.option["text"].get()
        self.arl_m.interval_suboption = self.suboption["text"].get()

        self.arl_m.set_user_df("interval")
        super().update_tree("data_view")
        super().update_tree("stats_view")


class GraphMaker(DropdownMaker):
    def __init__(self, gui, gui_dict, arl_m, option=None, suboption=None) -> None:
        super().__init__(gui, gui_dict, arl_m, option, suboption)
        self.arl_v = ARLVisualizer(gui)

    def update_settings(self) -> None:
        self.arl_m.set_graph_df(self.option["text"].get())
        self.arl_v.graph_display(self.option["text"].get(), self.arl_m.graph_df)