import numpy as np

class EverydayPlotter:
    def __init__(self, gui, fig=None, ax=None, canvas=None) -> None:
        self.graph_option_list = ["Bar Chart", "Line Chart", "Scatterplot"]
        self.gui = gui
        self.fig = fig
        self.ax = ax
        self.canvas = canvas
        
        self.inbound_kwargs = {
            "color" : "limegreen",
            "label" : "Inbound",
        }

        self.outbound_kwargs = {
            "color" : "indianred",
            "label" : "Outbound",
        }
    
    
    def draw_plot(self, graph_type, graph_df) -> None:
        inbound_x, inbound_y = graph_df["inbound"]
        outbound_x, outbound_y = graph_df["outbound"]

        match graph_type:
            case "Bar Chart":
                length_x = np.arange(len(inbound_x))

                # plotting the bars
                self.ax.bar(length_x-0.2, inbound_y, width=0.4, **self.inbound_kwargs)
                self.ax.bar(length_x+0.2, outbound_y, width=0.4, **self.outbound_kwargs)

                # set the xticks
                self.ax.set_xticks(length_x, inbound_x, fontsize=8, rotation=60)

            case "Line Chart":
                # plotting the bars
                self.ax.plot(inbound_x, inbound_y, **self.inbound_kwargs)
                self.ax.plot(outbound_x, outbound_y, **self.outbound_kwargs)


            case "Scatterplot":
                self.ax.scatter(inbound_x, inbound_y, **self.inbound_kwargs)
                self.ax.scatter(outbound_x, outbound_y, **self.outbound_kwargs)

            case _:
                raise ValueError("Invalid graph type!")
        

        self.ax.set_title(f"{graph_type} of Inbound and Outbound Passengers")
        self.ax.set_xlabel("Day/Week/Month")
        self.ax.set_ylabel("Passengers amount")
        self.ax.tick_params(axis='both', labelsize=8, rotation=60)
        self.ax.legend()
        self.canvas.draw()