import tkinter as tk
from tkinter import ttk

from arl_manager import ARLManager
from dropdown_maker import *

class GUIFacade:
    def __init__(self, gui) -> None:
        self.graph_option_list = ["Histogram", "Boxplot", "Bar Chart", "Line Chart", "Scatterplot"]
        self.gui = gui
        self.arl_m = ARLManager()
        
        self.gui_dict = {
            "arl_label" : tk.Label(self.gui, text="ARL Analysis and Data Visualization 2565", font=("Tahoma", 16)),
            "data_view" : ttk.Treeview(self.gui, show=["headings"]),
            "stats_view" : ttk.Treeview(self.gui, show=["headings"]),
        }

        self.filter_option = {
            "text" : tk.StringVar(value="Please select filter option"),
            "values" : self.arl_m.filter_option_list,
            "dd" : None,
        }

        self.filter_suboption = {
            "text" : tk.StringVar(value="Please select filter sub-option"),
            "values" : self.arl_m.filter_suboption_list,
            "dd" : None,
        }
        
        self.interval_option = {
            "text" : tk.StringVar(value="Please select interval option"),
            "values" : self.arl_m.interval_option_list,
            "dd" : None,
        }
        
        self.interval_suboption = {
            "text" : tk.StringVar(value="Please select interval sub-option"),
            "values" : self.arl_m.interval_suboption_list,
            "dd" : None,
        }

        self.graph_option = {
            "text" : tk.StringVar(value="Please select graph type"),
            "values" : self.graph_option_list,
            "dd" : None,
        }
        
        self.graph_maker = GraphMaker(self.gui, self.gui_dict, self.arl_m, self.graph_option)
        self.filter_option_maker = FilterOptionMaker(self.gui, self.gui_dict, self.arl_m,\
                                            self.filter_option, self.filter_suboption)
        self.filter_suboption_maker = FilterSuboptionMaker(self.gui, self.gui_dict, self.arl_m,\
                                                    self.filter_option, self.filter_suboption)
        self.interval_option_maker = IntervalOptionMaker(self.gui, self.gui_dict, self.arl_m,\
                                                self.interval_option, self.interval_suboption)
        self.interval_suboption_maker = IntervalSuboptionMaker(self.gui, self.gui_dict, self.arl_m,\
                                                        self.interval_option, self.interval_suboption)


    def setup_dropdown_settings(self) -> None:
        self.filter_option_maker.setup_dropdown()
        self.filter_suboption_maker.setup_dropdown()
        self.interval_option_maker.setup_dropdown()
        self.interval_suboption_maker.setup_dropdown()
        self.graph_maker.setup_dropdown()
        
        self.filter_option_maker.update_dropdown()
        self.filter_suboption_maker.update_dropdown()
        self.interval_option_maker.update_dropdown()
        self.interval_suboption_maker.update_dropdown()
        self.graph_maker.update_dropdown()


    def place_widgets(self) -> None:
        self.gui_dict["arl_label"].pack()
        self.setup_dropdown_settings()
        self.gui_dict["data_view"].place(x=0, y=200, relx=0.5, rely=0.15, anchor=tk.CENTER)
        self.gui_dict["stats_view"].place(x=-400, y=200, relx=0.5, rely=0.5, anchor=tk.CENTER)

        self.arl_m.set_graph_df("Histogram")
        self.graph_maker.arl_v.graph_display("Histogram", self.arl_m.graph_df)
        self.graph_maker.arl_v.canvas.get_tk_widget().place(x=50, y=220, relx=0.6, rely=0.5, anchor=tk.CENTER)
